@@ -133,7 +133,7 @@ init (GnomePilotPDialog *gppd)
 	gppd->priv = priv;
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings");
+	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings", NULL);
 	if (!priv->xml) {
 		g_message ("gnome-pilot-pdialog init(): Could not load the Glade XML file!");
 		goto error;
@@ -166,15 +166,12 @@ gnome_pilot_pdialog_new (GnomePilotClient *gpc, PilotState *state, GPilotPilot *
 	fill_widgets (gppd);
 	init_widgets (gppd);
 
-	gtk_signal_connect (GTK_OBJECT (gpc),
-			    GNOME_PILOT_CLIENT_SIGNAL_COMPLETED_REQUEST (gppd_request_completed), 
-			    gppd);
-	gtk_signal_connect (GTK_OBJECT (gpc),
-			    GNOME_PILOT_CLIENT_SIGNAL_USER_INFO (gppd_userinfo_requested), 
-			    gppd);
-	gtk_signal_connect (GTK_OBJECT (gpc), 
-			    GNOME_PILOT_CLIENT_SIGNAL_SYSTEM_INFO (gppd_system_info_requested), 
-			    gppd);
+	gnome_pilot_client_connect__completed_request (gpc, gppd_request_completed, 
+						       gppd);
+	gnome_pilot_client_connect__user_info (gpc, gppd_userinfo_requested, 
+					       gppd);
+	gnome_pilot_client_connect__system_info (gpc, gppd_system_info_requested, 
+						 gppd);
 	
 	return object;
 }
@@ -267,13 +264,14 @@ fill_widgets (GnomePilotPDialog *gppd)
 }
 
 gboolean
-gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd)
+gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd, GtkWindow *parent)
 {
 	GnomePilotPDialogPrivate *priv;
 	gint btn;
 	
 	priv = gppd->priv;
 	
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->dialog), parent);
 	btn = gnome_dialog_run (GNOME_DIALOG (priv->dialog));
 	
 	if (btn == 0)
@@ -382,6 +380,8 @@ gppd_sync_dialog (GnomePilotPDialog *gppd,
 	priv->sync_dialog = gnome_message_box_new (txt, GNOME_MESSAGE_BOX_GENERIC, GNOME_STOCK_BUTTON_CANCEL, NULL);
 	g_free (txt);
 
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->sync_dialog), GTK_WINDOW (priv->dialog));
+
 	gnome_dialog_button_connect (GNOME_DIALOG (priv->sync_dialog), 0, gppd_cancel_sync, gppd);
 	gnome_dialog_run_and_close (GNOME_DIALOG (priv->sync_dialog));
 }
