@@ -372,7 +372,7 @@ iterate_dbs (gint pfd,
 						dbinfo);
 
 		} else {
-			LOG ("Base %s is to be ignored by sync", PI_DBINFO (dbinfo)->name);
+			LOG (("Base %s is to be ignored by sync", PI_DBINFO (dbinfo)->name));
 			continue;
 		}
 		g_free (dbinfo); 
@@ -551,7 +551,7 @@ install_db_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier) {
 
 	g_free (pilot_name);
 	orbed_notify_completion (&req);
-};
+}
 
 static void
 install_foreach (GnomePilotConduit *conduit,
@@ -780,7 +780,6 @@ run_conduit_sync_foreach (GPilotRequest *req,
 	GList *clist,*blist,*flist;
 	int err;
 
-	g_return_if_fail (conduit!=NULL);
 	g_return_if_fail (carrier!=NULL);
 
 	err = 0;
